require("love.filesystem")
require("love.timer")
local self_thread = love.thread.getThread()

-- watch the file system for changes

function getExtension(file)
	local x, y, z = string.match(file, "(.-)([^\\]-([^%.]+))$")
	return z
end

function findLuaFilesInDirectory(directory, callOnFind)
	local files = love.filesystem.enumerate(directory)
	for k, file in ipairs(files) do
		-- if the file ends with .lua, then deal with it
		if getExtension(file) == 'lua' then
			callOnFind(directory .. file)
		end
		-- todo: if it is a directory, then recurse
		if love.filesystem.isDirectory(file) then
			findLuaFilesInDirectory(file .. "/", callOnFind)
		end
	end
end

local watchedFiles = {}

-- should first build the list of watched files, so it doesn't send all the lua files immediately upon starting
findLuaFilesInDirectory("", function(file)
	watchedFiles[file] = love.filesystem.getLastModified(file)
end)

-- just loop forever
-- watching for changes and new files
while 1 do
	findLuaFilesInDirectory("", function(file)
		if not watchedFiles[file] or watchedFiles[file] < love.filesystem.getLastModified(file) then
			watchedFiles[file] = love.filesystem.getLastModified(file)
			self_thread:set("new_file", file)
		end
	end)
    love.timer.sleep(0.01)
end